@@ -1,4 +1,4 @@
-__version__ = "0.5"
+__version__ = "0.7"
 
 from configparser import ConfigParser
 from pathlib import Path
@@ -48,7 +48,7 @@ class Config:
 
     @classmethod
     def database_connection_str(cls, database):
-        return URL(
+        return URL.create(
             drivername=DRIVERNAME,
             username=cls.USERNAME,
             password=cls.PASSWORD,
@@ -73,6 +73,13 @@ class DbSession:
     factory = None
     engine = None
 
+    @staticmethod
+    def create_engine(database, echo=False):
+        return create_engine(
+            Config.database_connection_str(database),
+            echo=echo,
+        )
+
     @classmethod
     def global_init(cls, test_db=False):
         if cls.factory:
@@ -83,10 +90,7 @@ class DbSession:
         if test_db:
             cls.database += "_test"
 
-        engine = create_engine(
-            Config.database_connection_str(cls.database),
-            echo=test_db,
-        )
+        engine = cls.create_engine(cls.database, echo=test_db)
 
         cls.engine = engine
         cls.factory = sessionmaker(bind=engine)
